/* Space out content a bit */
body {
  padding-top: 20px;
  padding-bottom: 20px;
}

/* Everything but the jumbotron gets side spacing for mobile first views */
.footer {
  padding-right: 15px;
  padding-left: 15px;
}

#datepicker-container,
#daterange-container,
#datepicker-container-ew {
    padding-top: 50px;
    padding-bottom: 50px;
}

/*.datepicker-sd {
    font-size:24px;
    height: 50px;
}*/

#footer {
  position: absolute;
  bottom: 0;
  width: 100%;
  /* Set the fixed height of the footer here */
  height: 60px;
  color: #999; /* IE8 proofing */
  color: rgba(255,255,255,.6);
}

#footer a{
    color: #fff;
    color: rgba(255,255,255,.85);
}

/* Customize container */
@media (min-width: 768px) {
  .container {
    max-width: 730px;
  }
}
.container-narrow > hr {
  margin: 30px 0;
}


/* Links */
a,
a:focus,
a:hover {
  color: #fff;
}

html {
  position: relative;
  min-height: 100%;
}

body {
  background-color: #333;
  background: url(static/img/sundown.jpg) no-repeat center center fixed;
  -webkit-background-size: cover;
  -moz-background-size: cover;
  -o-background-size: cover;
  background-size: cover;
  /* Margin bottom by footer height */
  margin-bottom: 60px;
  color: #fff;
  text-shadow: 0 1px 3px rgba(0,0,0,.5);
  /*box-shadow: inset 0 0 100px rgba(0,0,0,.5);*/
}
.page-header {
    border-bottom: none;
}

.nav > li {
  display: inline-block;
}
.nav > li + li {
  margin-left: 20px;
}
.nav > li > a {
  padding-right: 0;
  padding-left: 0;
  font-size: 16px;

  color: #fff; /* IE8 proofing */
  color: rgba(255,255,255,.75);
  border-bottom: 2px solid transparent;
}
.nav > li > a:hover,
.nav > li > a:focus {
  background-color: transparent;
  border-bottom-color: rgba(255,255,255,.25);
}
.nav > .active > a,
.nav > .active > a:hover,
.nav > .active > a:focus {
  color: #fff;
  border-bottom-color: #fff;
}

.table {
    background-color: rgba(0,0,0,.3);
}
